#
# spec file for package alpine
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           alpine
# For debugging only:
%define		build_vanilla		0
Summary:        Mail User Agent
License:        Apache-2.0
Group:          Productivity/Networking/Email/Clients
Version:        2.21
Release:        lp151.3.1
Url:            http://alpine.x10host.com/alpine/

# direct download does not work for openSUSE:Factory
# Source:         http://patches.freeiz.com/alpine/release/src/%name-%version.tar.xz
Source:         %name-%version.tar.xz
Source1:        %name.png
Source2:        %name.desktop
Patch2:         make-use-of-strncat-safer.diff
Patch3:         operation-may-be-undefined-warning.diff
Patch4:         fix-implicit.patch
Patch5:         alpine-gcc44.diff
Patch6:         alpine-timestamp.patch
Patch7:         alpine-pinepw.patch
Patch10:        pico-fix-spurious-undef-warnings.diff
Patch20:        pine-expression-warnings.diff
Patch60:        signal-and-panic-improvements.diff
#
# Eduardo Chappa's patches.
# http://patches.freeiz.com/alpine/
#
Patch600:       chappa-colortext.patch
Patch601:       chappa-fancy.patch
Patch603:       chappa-insertpat.patch
Patch604:       chappa-maildir.patch
Patch605:       chappa-WrtAcc.patch
Patch614:       chappa-fillpara.patch
Patch615:       chappa-fromheader.patch
Patch616:       chappa-rules.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf >= 2.69
BuildRequires:  krb5-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  update-desktop-files
BuildRequires:  xz
# pgp4pine requires pine: (6.20 is what alpine writes to ~/.pinerc)
Provides:       pine = 6.20
Obsoletes:      pine4
Provides:       pine4

%description
Alpine is a display-oriented email client that is suitable for both
the inexperienced email user as well as for the most demanding of
power users. Alpine is based on the Pine® Message System, which was
also developed at the University of Washington. Alpine can be learned
by exploration and the use of context-sensitive help. The user
experience is highly customizable through the use of the Alpine Setup
command.

%package -n pico
Summary:        A small, easy to use editor
Group:          Productivity/Editors/Other
Version:        5.07
Release:        lp151.3.1

%description -n pico
Pico is a simple, display-oriented text editor based on the Pine
message system composer. As with Pine, commands are displayed at the
bottom of the screen, and context-sensitive help is provided.
Characters are inserted into the text as they are typed.

%package -n pilot
Summary:        Simple file system browser
Group:          Productivity/File utilities
Version:        2.99
Release:        lp151.3.1

%description -n pilot
Pilot is a simple, display-oriented file system browser based on the
Pine message system composer. As with Pine, commands are displayed at
the bottom of the screen, and context-sensitive help is provided.

%prep
%setup -q
%if !%{build_vanilla}
#
# This is here to support checking if any patches add new warnings:
#
if [ ! -s %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log ]; then
	echo "No warnings check possible, set build_vanilla to 1 and"
	echo "add compile-warnings-%{suse_version}-%{_arch}.log from"
	echo "that build to the rpm build process so that it's found here".
else
	sed 's/:[0-9]*//' %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log \
		>compile-warnings-allowed.log 
fi
#
# "Chappa" patches
#
%patch600 -p1
%patch601 -p1
%patch603 -p1
%patch604 -p1
%patch605 -p1
%patch614 -p1
%patch615 -p1
%patch616 -p1
#
# SuSE patches - warning fixes, etc:
#
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch10 -p1
%patch20 -p1
%patch60 -p1
%endif # End of "if !{build_vanilla}"

%build
#
# Comment on disabled warnings: The disabled warnings are rather harmless
# and disabling them allows to focus on the really serious warnings:
#
export CFLAGS="${RPM_OPT_FLAGS/-O2/-Os} \
		-Wno-unused-value -fno-strict-aliasing -Wno-pointer-sign -Wno-unused \
		-Wno-address \
"
#
# On -Waddress:
#
# Added with gcc-4.2: It warns when the address of a variable (not a pointer)
# is used in an expression. Since addresses of variables are always non-zero,
# they are always true and can be safely removed from the expression,
# but the code is safe nontheless.
#
# -Waddress generates >100 warnings in alpine and we disabled them to 
# concentrate on the really important warnings which could be real bugs better.
#
:
#
# Used in conjunction with signal-and-panic-improvements.diff:
#
export LDFLAGS="-rdynamic" # -rdynamic is used for backtrace_symbols:
:
autoreconf -fiv
%configure \
	--with-ssl-dir=/usr				\
	--with-smtp-msa=/usr/sbin/sendmail		\
	--with-password-prog=/usr/bin/passwd		\
	--with-npa=/usr/bin/inews			\
	--with-spellcheck-prog="please set Speller to eg. 'aspell -c' in SETUP/Configuration"\
	--with-system-pinerc=%_sysconfdir/pine.conf		\
	--with-system-fixed-pinerc=%_sysconfdir/pine.conf.fixed \
	--with-debug-level=0				\
	--with-debug-files=2				\
	--with-file=.alpine-debug			\
	--with-default-mail-directory=Mail		\
	--with-web-bin=%_libdir/%name                   \
	--with-passfile=.pinepw || {
	grep -B9 -A20 'failed program was' config.log | grep -A24 checking
	exit 5
}
%{?fedora_version: tag=LFD}
%{?mandriva_version: tag=LMD}
%{?redhat_version: tag=LRH}
%{?centos_version: tag=LRH}
%{?suse_version: tag=LSU}
perl -i -pe 's{(define SYSTYPE) "LNX"}{$1 "'"$tag"'"}g' include/config.h

#
# imap does not use CFLAGS from configure, needs EXTRACFLAGS/EXTRALDFLAGS:
#
make %{?_smp_mflags} EXTRACFLAGS="$CFLAGS" EXTRALDFLAGS="$EXTRALDFLAGS"

%install
make install DESTDIR=%buildroot
#
# When called as alpinef, alpine uses function keys instead of Control keys:
#
ln $RPM_BUILD_ROOT%{_bindir}/alpine $RPM_BUILD_ROOT%{_bindir}/alpinef
install    -m755 imap/mailutil/mailutil $RPM_BUILD_ROOT%{_bindir}
install -m644 imap/src/mailutil/mailutil.1	$RPM_BUILD_ROOT%{_mandir}/man1/
install -D -m644 %{SOURCE1} $RPM_BUILD_ROOT/usr/share/pixmaps/%name.png
install -D -m644 %{SOURCE2} $RPM_BUILD_ROOT/usr/share/applications/%name.desktop
%suse_update_desktop_file %name
:
ln -sf		 alpine			$RPM_BUILD_ROOT%{_bindir}/pine
:
install -m755 pico/{pico,pilot}		$RPM_BUILD_ROOT%{_bindir}
install -m644 doc/man1/{pico.1,pilot.1}	$RPM_BUILD_ROOT%{_mandir}/man1/

%check
#since where are no logs in the package at the moment, there are no checks,
#but the warning logs can be recreated for regresstion tracking in warnings:
if [  -s %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log ]; then
    grep -e '^[a-z0-9_]*.[cho]:' -e 'Entering directory' make.log |
	sed "s/^make\[.\]: //;/Entering directory/s/[\`']//g;" \
	>compile-warnings-%{suse_version}-%{_arch}.log
    # Sort the combined allowed warnings:
    grep -v -e 'In function' -e 'Entering directory' \
	compile-warnings-allowed.log |
	    sort -u > compile-warnings-%{suse_version}-%{_arch}-reference.sort
    # Sort the warnings which occured now:
    grep -v -e 'In function' -e 'Entering directory' \
	compile-warnings-%{suse_version}-%{_arch}.log |
	    sed 's/:[0-9]*//' | sort -u \
		>compile-warnings-%{suse_version}-%{_arch}-thisbuild.sort
    # diff them:
    diff compile-warnings-%{suse_version}-%{_arch}-{reference,thisbuild}.sort |
	tee	  compile-warnings-%{suse_version}-%{_arch}-sorted.diff
    if test    -s compile-warnings-%{suse_version}-%{_arch}-sorted.diff; then
	grep '^>' compile-warnings-%{suse_version}-%{_arch}-sorted.diff >new-warnings ||:
	if [ -s new-warnings ]; then
		diff -u %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log \
			compile-warnings-%{suse_version}-%{_arch}.log ||
		echo "New warnings:"
		cat new-warnings
		sed 's/> //;s/:/:[0-9]*:/' new-warnings >new-warnings.pattern
		: diff:  %_builddir}/compile-warnings-%{suse_version}-%{_arch}-sorted.diff
		grep -B1 -f new-warnings.pattern compile-warnings-%{suse_version}-%{_arch}.log
		grep -e 'Entering directory' -f new-warnings.pattern \
			compile-warnings-%{suse_version}-%{_arch}.log |
				grep -B1 -f new-warnings.pattern |
					tee warnings.where
		while IFS='[: ]' read file line message; do
			if [ "$file" = Entering ]; then
				dir="${message#%_builddir/%buildsubdir/}"
			else
				path="$dir/$file"
				echo "$path:$line: $message"	>>warnings-with-code
				head -"$line" "$path"|tail -1	>>warnings-with-code
			fi
		done <warnings.where
		cat warnings-with-code
		exit 5
	else
		echo "Fixed warnings:"
		grep '^<' compile-warnings-%{suse_version}-%{_arch}-sorted.diff
	fi
    else
	echo "No fixed warnings and no new warnings"
    fi
fi

%files
%defattr(-, root, root)
%doc %{_mandir}/man1/alpine.*
%doc %{_mandir}/man1/rpdump.*
%doc %{_mandir}/man1/rpload.*
%doc %{_mandir}/man1/mailutil.*
%doc README NOTICE LICENSE
%doc doc/mailcap.unx doc/mime.types doc/tech-notes/tech-notes.txt doc/tech-notes/*.html
%{_bindir}/*pine
%{_bindir}/alpinef
%{_bindir}/rp*
%{_bindir}/mailutil
/usr/share/applications/%name.desktop
/usr/share/pixmaps/%name.png

%files -n pico
%defattr(-, root, root)
%{_bindir}/pico
%doc %{_mandir}/man1/pico.*

%files -n pilot
%defattr(-, root, root)
%{_bindir}/pilot
%doc %{_mandir}/man1/pilot.*

%changelog
* Thu May  2 2019 Reinhard Max <max@suse.com>
- Fix initialisation of encrypted password store (bsc#1133597,
  alpine-pinepw.patch).
* Thu Nov  8 2018 Michal Svec <msvec@suse.com>
- updated upstream URL
* Mon Jul  3 2017 jengelh@inai.de
- imap is bundled with alpine since a while, so there is no need
  for imap-devel anymore (whose removal is planned for
  openSUSE:Factory).
* Tue Mar 21 2017 opensuse@dstoecker.de
- add chappa patch to add own rules (chappa-rules.patch)
- add chappa patch to change from header (chappa-fromheader.patch)
- add chappa patch to better justify paragraphs (chappa-fillpara.patch)
- drop empty lint.diff
* Tue Mar 21 2017 max@suse.com
- New version 2.21:
  * New SHORTSUBJECT, SHORTSUBJKEY and SHORTSUBJKEYINIT token for
    index format
  * New SMARTTIME24 token for index screen.
  * Added support for RFC 2971 - IMAP ID extension.
  * SMIME: Upgrade the default signature digest from SHA-1 to
    SHA-256.
  * SMIME: Turn off automatic signing and encrypting of a message
    when bouncing.
  * The complete change list can be viewed by pressing "R"
    in the Alpine main menu.
- Updated "Chappa" patches to the latest version.
- Obsolete patches:
  * alpine-no-add-needed.patch
  * chappa-ignoresize.patch
  * chappa-unixnullbug.patch
  * pico-stripwhitespace.diff
  * pine-nonvoid-function.patch
* Mon Apr  4 2016 kukuk@suse.de
- Remove BuildRequires for libgssglue (via libgssapi provides),
  unused since krb5_gssapi is used.
* Fri Mar  4 2016 olaf@aepfle.de
- Remove timestamp from binary
  alpine-timestamp.patch
* Wed Mar 25 2015 jengelh@inai.de
- Update to new upstream release 2.20
  * Upgrade UW-IMAP to Panda IMAP from github.com/jonabbey/panda-imap
  * S/MIME: Add screen to manage certificates.
  * S/MIME: Signatures are validated using the user's certificates
  instead of the ones included in the message. Behavior can be
  disabled by disabling the option "Validate Using Certificate
  Store Only" which is enabled by default.
  * S/MIME: add the sender certificate to the list of certificates
  in encrypted messages to make it possible for the sender to
  decrypt the message they sent.
  * S/MIME: Forwarding a message will include the signed part as part
  of the text and not as a multipart message, just as the reply
  command does.
  * Add support to selective expunge through a subcommand of the
  select-apply commands.
  * Pico: New subcommand of the search command, allows to reverse the
  direction of search.
  * Add /tls1, /tls1_1, /tls1_2 and /dtls1 to the definition of a
  server to use different ways to connect using ssl, for example
  {server.com/tls1} will attempt to connect to server.com at the
  ssl imap port (port 993) and establish a connection using TLSv1.
  These flags can be used in conjunction with the /ssl flag, the
  ssl flag is redundant. Conversely, however, the /ssl flag does
  not imply any of these flags; the /ssl flag means SSLv3 or, if
  not available, SSLv2 in the SSL port.
  * Alpine does not attempt to automatically reopen a collection that
  was not opened due to cancellation by the user. Instead, the user
  must try to open it explicitly.
  * Experimental: Write the content-type of a message in lowercase,
  as some non-compliant servers do not understand uppercase
  content-type.
  * Opening a folder updates recent count in maildrops (this
  already works for other types of folders)
  * Pico: Justification works without need of a predefined quote
  string. This allows justification of blocks of text that are
  indented with spaces.
  * Decode the name of attachment names, so they can be written as
  part of the description of the part.
  * Replace tabs by spaces in From and Subject fields to control for
  size in screen of these fields. Change only in index screen
  display.
- Drop alpine-month_name-utf8.patch (solved differently upstream),
  drop alpine-mime-type-workaround.patch (merged upstream)
- Add lint.diff to workaround new source code problems
* Mon Mar  3 2014 jengelh@inai.de
- The pico and pilot standalone programs have version numbers of
  their own; expose these in the .spec file
* Wed Jan 22 2014 max@suse.com
- Add alpine-mime-type-workaround.patch:
  Send mime type in lowercase to work around MUAs that can't cope
  with upper case mime type strings in the Content-Type header
  such as the webmailer of GMX.  This is a backport from the
  current development release and will become obsolete with the
  next version upgrade.
* Mon Sep  2 2013 jengelh@inai.de
- Update to new upstream release 2.11
  * Increase encryption of S/MIME encrypted messages.
  * Pico: Improvements in justification of paragraphs: lines that
  begin with a quote string, followed by a space were considered
  individual paragraphs, now they are considered part of a paragraph.
  * Unix Alpine: Allow local .pinerc file to be a symbolic link.
  * Experimental extended support of recognition of UTF-8 in urls
  * Added recognition of ws and wss URIs.
  * Add ability to color folder names, directory names, and text in
  the FOLDER SCREEN.
  * Add the ability to color any token used in the display of the
  INDEX SCREEN.
  * New option preserve-original-fields that adds the ability to
  preserve To: and Cc: fields when replying to a message, as
  specified by original sender.
  * Added Quota subcommands for printing, forwarding, saving, etc.
- Refresh from homepage (and save as unified): chappa-*.patch
- Refresh for -p1: operation-may-be-undefined-warning.diff,
  fix-implicit.patch, alpine-gcc44.diff
- Drop quilt-patches/alpine-2.00-as_needed.patch (merged upstream)
* Wed May 22 2013 jengelh@inai.de
- Update to new upstream release 2.10
  * Quota report for IMAP folders that support it
  (press the "@" command in the index screen of such folder).
  * Search a folder for the content of any header with the ";"
  command.
  * Foreign characters are decoded correctly in IMAP folders.
  * Recognition of proper mime type for docx, xlsx, and pptx files.
  * When composing a message, Alpine will create a new thread when
  the subject is erased.
- Uncompress patches, since quilt does not like working with them
- Remove because merged upstream: chappa-filterflagbug.patch(.gz),
  chappa-nlinfobug.patch(.gz), chappa-replacebug.patch(.gz),
  chappa-searchheader.patch(.gz), chappa-streamlock.patch(.gz)
- Rediff to clear fuzz: alpine-no-add-needed.patch,
  pine-nonvoid-function.patch
- Remove because no longer applies and total lack of description
  as per Patch Guidelines:
  alpine-no-add-needed.patch
* Wed May 22 2013 jengelh@inai.de
- Remove old SUSE definitions
* Fri Jul 27 2012 aj@suse.de
- Include sys/resource.h for getrlimit.
* Wed Feb  8 2012 puzel@suse.com
- clean up spec file
* Mon Oct 17 2011 max@suse.com
- Fix two instances of premature closedir() and a potential buffer
  overflow in the maildir handler (alpine-maildir-closedir.patch).
* Tue Oct 11 2011 max@suse.com
- Fix and extend operation-may-be-undefined-warning.diff
  (bnc#558841)
- Overhaul RPM summary and description.
- Month names containing non-ASCII characters were rendered
  incorrectly in non-UTF8 locales (bnc#597744).
* Mon Oct 10 2011 max@suse.com
- Explicitly set the ssl prefix dir to fix build on ARM.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sat Sep  3 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Jul 29 2009 max@suse.de
- Included the latest bugfix-patches from Eduardo Chappa:
- replacebug: Fix a bug in Pico which makes it not update the
  screen.
- unixnullbug: Fix a bug that makes Alpine crash when opening a
  unix type folder.
- streamlock: Fix a bug that makes Alpine crash when suspending it.
- filterflagbug: Fix a bug in Alpine that makes it not to set a
  flag in a filtered message (bnc#342075).
- nlinfobug: Fix a bug in Pico and Pilot that makes them crash
  for bad locale information.
- unverified: Fix a bug that makes Alpine not to give a warning
  if the Newsgroup header is present
* Sat Jun 20 2009 cmorve69@yahoo.es
- fixed build with --as-needed
* Tue Jun  2 2009 coolo@suse.de
- fix compilation with gcc44
* Wed Oct 15 2008 max@suse.de
- lzma is no longer needed for building.
* Thu Oct  9 2008 meissner@suse.de
- added unistd.h for prototypes
* Mon Sep 29 2008 max@suse.de
- Update to version 2.00 and the related Chappa patches.
- Changes include:
  * Experimental S/MIME support added in UNIX versions of Alpine
  * Enhance address completion in the composer (TAB command)
  * Add line wrapping when displaying PRE formatted sections of
    HTML
  * Fix a crash when using tab-completion for selecting a Save
    filename
  * Fix viewing, printing, exporting, replying, and bouncing of
    message digests.
  * The Unknown Character Set option did not work correctly
    interpreting unknown characters in message headers
  * Crash when TABing to next folder, the next folder with new
    mail is a POP folder, and there is a more than 10 minute
    pause between typing the TAB and typing the Yes
- For more details, see:
  http://www.washington.edu/alpine/changes/1.10-to-2.00.html
* Sat Apr 26 2008 coolo@suse.de
- fix build
* Fri Apr 25 2008 bk@suse.de
- Update to alpine-1.10 and update fixes suggested for this version
* Fri Jan 11 2008 bk@suse.de
- Update to alpine-1.00 and apply fixes suggested for this version
* Tue Sep 25 2007 bk@suse.de
- Use only select patches from Eduardo (fixes crash in mail reader)
* Wed Sep 19 2007 bk@suse.de
- Remove files with unclear license from packaged sources (#308533)
- Add small bug fix: Postponed messages which were labelled as UTF-8
- Spec file cleanup: Comments improved, obsoleted some warning flags
* Tue Sep  4 2007 bk@suse.de
- Update to final prerelease 0.9999 with updates from Eduardo Chappa
* Thu Aug  9 2007 bk@suse.de
- add a number of critcally needed fixes for some crashes (and more)
* Thu Aug  2 2007 bk@suse.de
- initial version 0.999 + assorted feature patches and some fixes
